@@ -1,4 +1,4 @@
-from utils.aws.ecs import AWSECSHandler
+from django_splint.utils.aws.ecs import AWSECSHandler
 
 
 class SplintTask(AWSECSHandler):
